import React, { useState } from 'react';
import { Link, useNavigate } from 'react-router-dom';
import { Menu, X, ShoppingCart, User, LogOut, FileText } from 'lucide-react';
import { Button } from './ui/button';
import { useCart } from '../contexts/CartContext';
import { useAuth } from '../contexts/AuthContext';

const Header = () => {
  const [isMenuOpen, setIsMenuOpen] = useState(false);
  const { state } = useCart();
  const { user, signOut } = useAuth();
  const navigate = useNavigate();

  const handleSignOut = async () => {
    await signOut();
    navigate('/');
  };

  return (
    <header className="bg-white shadow-sm sticky top-0 z-50">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex justify-between items-center h-16">
          {/* Logo */}
          <div className="flex-shrink-0">
            <Link to="/" className="flex items-center">
              <div className="w-10 h-10 bg-gradient-to-br from-drive-primary to-drive-secondary rounded-lg flex items-center justify-center mr-3">
                <span className="text-white font-bold text-lg">D</span>
              </div>
              <span className="text-xl font-bold text-drive-gray-900">DriveInProgress</span>
            </Link>
          </div>

          {/* Navigation desktop */}
          <nav className="hidden md:flex items-center space-x-8">
            <Link to="/catalogue" className="text-drive-gray-700 hover:text-drive-primary transition-colors">
              Catalogue
            </Link>
            <Link to="/blog" className="text-drive-gray-700 hover:text-drive-primary transition-colors">
              Blog
            </Link>
            <Link to="/contact" className="text-drive-gray-700 hover:text-drive-primary transition-colors">
              Contact
            </Link>
          </nav>

          {/* Actions */}
          <div className="hidden md:flex items-center space-x-4">
            {user ? (
              <>
                <Link to="/mes-documents">
                  <Button variant="ghost" className="flex items-center space-x-2">
                    <FileText className="w-4 h-4" />
                    <span>Mes documents</span>
                  </Button>
                </Link>
                <Link to="/dashboard">
                  <Button variant="ghost" className="flex items-center space-x-2">
                    <User className="w-4 h-4" />
                    <span>Mon espace</span>
                  </Button>
                </Link>
                <Link to="/admin/files">
                  <Button variant="ghost" className="flex items-center space-x-2 text-blue-600">
                    <FileText className="w-4 h-4" />
                    <span>Admin</span>
                  </Button>
                </Link>
                <Button 
                  variant="ghost" 
                  onClick={handleSignOut}
                  className="flex items-center space-x-2 text-red-600 hover:text-red-700"
                >
                  <LogOut className="w-4 h-4" />
                  <span>Déconnexion</span>
                </Button>
              </>
            ) : (
              <>
                <Link to="/login">
                  <Button variant="ghost">Connexion</Button>
                </Link>
                <Link to="/signup">
                  <Button className="bg-gradient-to-r from-drive-primary to-drive-secondary hover:from-drive-primary/90 hover:to-drive-secondary/90">
                    Inscription
                  </Button>
                </Link>
              </>
            )}
            
            <Link to="/panier" className="relative">
              <Button variant="ghost" size="icon">
                <ShoppingCart className="h-5 w-5" />
                {state.itemCount > 0 && (
                  <span className="absolute -top-1 -right-1 bg-drive-primary text-white text-xs rounded-full h-5 w-5 flex items-center justify-center">
                    {state.itemCount}
                  </span>
                )}
              </Button>
            </Link>
          </div>

          {/* Menu mobile button */}
          <div className="md:hidden">
            <Button
              variant="ghost"
              size="icon"
              onClick={() => setIsMenuOpen(!isMenuOpen)}
            >
              {isMenuOpen ? <X className="h-6 w-6" /> : <Menu className="h-6 w-6" />}
            </Button>
          </div>
        </div>

        {/* Menu mobile */}
        {isMenuOpen && (
          <div className="md:hidden">
            <div className="px-2 pt-2 pb-3 space-y-1 sm:px-3 bg-white border-t">
              <Link
                to="/catalogue"
                className="block px-3 py-2 text-drive-gray-700 hover:text-drive-primary"
                onClick={() => setIsMenuOpen(false)}
              >
                Catalogue
              </Link>
              <Link
                to="/blog"
                className="block px-3 py-2 text-drive-gray-700 hover:text-drive-primary"
                onClick={() => setIsMenuOpen(false)}
              >
                Blog
              </Link>
              <Link
                to="/contact"
                className="block px-3 py-2 text-drive-gray-700 hover:text-drive-primary"
                onClick={() => setIsMenuOpen(false)}
              >
                Contact
              </Link>
              
              {user ? (
                <>
                  <Link
                    to="/mes-documents"
                    className="flex items-center px-3 py-2 text-drive-gray-700 hover:text-drive-primary"
                    onClick={() => setIsMenuOpen(false)}
                  >
                    <FileText className="h-5 w-5 mr-2" />
                    Mes documents
                  </Link>
                  <Link
                    to="/dashboard"
                    className="block px-3 py-2 text-drive-gray-700 hover:text-drive-primary"
                    onClick={() => setIsMenuOpen(false)}
                  >
                    Mon espace
                  </Link>
                  <Link
                    to="/admin/files"
                    className="flex items-center px-3 py-2 text-blue-600 hover:text-blue-700"
                    onClick={() => setIsMenuOpen(false)}
                  >
                    <FileText className="h-5 w-5 mr-2" />
                    Administration
                  </Link>
                  <button
                    onClick={() => {
                      handleSignOut();
                      setIsMenuOpen(false);
                    }}
                    className="block w-full text-left px-3 py-2 text-red-600 hover:text-red-700"
                  >
                    Déconnexion
                  </button>
                </>
              ) : (
                <>
                  <Link
                    to="/login"
                    className="block px-3 py-2 text-drive-gray-700 hover:text-drive-primary"
                    onClick={() => setIsMenuOpen(false)}
                  >
                    Connexion
                  </Link>
                  <Link
                    to="/signup"
                    className="block px-3 py-2 text-drive-gray-700 hover:text-drive-primary"
                    onClick={() => setIsMenuOpen(false)}
                  >
                    Inscription
                  </Link>
                </>
              )}
              
              <Link
                to="/panier"
                className="flex items-center px-3 py-2 text-drive-gray-700 hover:text-drive-primary"
                onClick={() => setIsMenuOpen(false)}
              >
                <ShoppingCart className="h-5 w-5 mr-2" />
                Panier
                {state.itemCount > 0 && (
                  <span className="ml-2 bg-drive-primary text-white text-xs rounded-full h-5 w-5 flex items-center justify-center">
                    {state.itemCount}
                  </span>
                )}
              </Link>
            </div>
          </div>
        )}
      </div>
    </header>
  );
};

export default Header;
